\n
\n\n\n\n
\n\n\n\n\n\n
\n\n\n
\n
\n
\n

## RC Allen 15Bk-1 Factory Lighted Directional Gyro Overhauled

\n
\n
\n
\n
$1145.00/Each
\n
+$1000 Core Exchange Charge
\n
\n
\n
\n
Part# 10-05690
MFR Model# RCA15BK-1
\n\n\n\n\n\n\n
\n
\n
\n
\n\n\n\n\n
\n
\n

\n
\n\nThe RCA15 Series electric directional gyro employs and electrically driven gyro motor and is a direct reading, azimuth indicator. Rotor run up time is 3 min. They have a built in inverter which converts aircraft DC power to the required AC voltage and frequency. May be used in both fixed wing and rotor wing aircraft and is easily installed in standard 3 1/8\" panel cut out. Power failure flag drops into view when supply voltage is lost or has dropped below a level for proper operation of the gyro. Azimuth indication range 360°. Altitude operation -1,000 to 40,000 feet. Internal 3 phase inverter prodeces high starting torque and increases gyro roto speed. Internal lighting provides even light distribution at any intensity level. calibrated to an accuracy of 3° maximum drift error after 10 minutes of ±1.5° scorsby motion. \r\n \r\nMeets of exceeds all requirements of FAA TSO C5c \r\nand Aeronautical Standard AS397. \r\n Made in the USA\n
\n

\n

\n
\n
\n\n
\n
\n

## Electrical Requirements

- Starting Current @ 14 VDC: 2.4A Max
- Running Current @ 14 VDC: 1.2A
- Starting Current @ 28 VDC:; 1.4A Max
- Running Current @28 VDC .6A
- Reccomended Circuit Breaker 3A

\n
\n
\n
\n
\n

## Dimensions

- Length: 6.7\"
- Width; 3.4\"
- Height: 3.4\"
- Weight; 2.3 pounds

\n
\n
\n
\n
\n
\n
\n
\n
\n
\n
\nUMA 14V Light Inverter PMA\n
\n
$91.75
\n
\n
\n
\n
\n
\nFalcon 3-1/8 Altimeter AlT20Mbf-3\n
\n
$616.00
\n
\n
\n
\n
\n
\nUMA 2-35-W Bezel Light\n
\n
$74.95
\n
\n
\n
\n
\n
\nACK A-30.9 Encoder RS232 42K\n
\n
$265.00
\n
\n
\n
\n
\n
\nUMA Temperature Probe 5/8-18 1B3 Lycoming Non-TSO\n
\n
$88.75
\n
\n
\n
\n
\n
\nA-930 Control 48\n
\n
$111.75
\n
\n
\n
\n
\n
\nGlass Fuse Agc-1 1Amp\n
\n
$0.30
\n
\n
\n
\n
\n
\nPrecision Pacmg-2 Universal Mounting Bracket Glare Shield / Deck Mount\n
\n
$91.75
\n
\n
\n
\n
\n
\nUMA 2-1/4 Light White With Cutout\n
\n
$76.75
\n
\n
\n
\n
\n
\nAN Fitting AN816-2D Nipple\n
\n
$4.70
\n
\n
\n
\n
\n
\nGlass Fuse Agc-3 3Amp\n
\n
$0.30
\n
\n
\n
\n
\n
\n
\n
\nFalcon Vacuum Directional Gyro\n
\n
$920.00
\n
\n
\n
\n
\n
\nSigma-Tek Directional Gyro 4000B-30\n
\n
$1045.00
\n
\n
\n
\n
\n
\nSkysports Electric Directional Gyro\n
\n
$1645.00
\n
\n
\n
\n
\n
\nMid-Continent Directional Gyro / Electric\n
\n
$3771.00
\n
\n
\n
\n
\n
\nRC Allen 11A-8 Vacuum Directional Gyro Overhauled TSO\n
\n
$645.00
\n
\n
\n
\n
\n
\nSigma-Tek 4000B / 4000Hr Series Standard Directional Gyro\n
\n
$2200.00
\n
\n
\n
\n
\n
\nRC Allen 11A Series Vacuum Directional Gyros\n
\n
$1125.00
\n
\n
\n
\n
\n
\nJPI EDM-730 Engine Monitoring System\n
\n
$4363.00
\n
\n
\n
\n
\n
\nFalcon Vertical Card Compass - 12V - Northern Hemisphere\n
\n
$399.00
\n
\n
\n
\n
\n
\nPrecision Vertical Card Compass PAI-700\n
\n
$835.00
\n
\n
\n
\n
\n
\nSkysports Vacuum Directional Gyro Gd031\n
\n
$835.00
\n
\n
\n
\n
\n
\nElectronics International CGR-30 Primary Engine Monitor System - Certified\n
\n
$8998.00
\n
\n
\n
\n
\n
\nMCI 3-Inch Turn Coordinator - 1394T100-7B\n
\n
$1335.00
\n
\n
\n
\n
\n
\nRC Allen 15 Series Directional Indicator Bk(28V)\n
\n
$2229.00
\n
\n
\n
\n
\n
\nRC Allen Turn Coordinators - 3 Inch FAA TSO\n
\n
$0.00
\n
\n
\n
\n
\n
\nRC Allen Vacuum DG Rca11A-15F\n
\n
$1125.00
\n
\n
\n
\n
\n
\nUnited 3-Inch / 3-Pointer Altimeters\n
\n
$1965.00
\n
\n
\n
\n
\n
\nRC Allen 15 Series Directional Indicator Ak (14V)\n
\n
$2229.00
\n
\n
\n
\n
\n
\n
\n
\n\n
\n
\nRC Allen Factory Overhauled RCA11A-8\n
\n
\n
$645.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRC Allen Factory Overhauled RCA26Bk-9\n
\n
\n
$1145.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRC Allen Factory Overhauled RCA26Bk-2\n
\n
\n
$1025.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRC Allen 26Ak-4 Factory Overhauled Attitude Indicator\n
\n
\n
$1145.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n
\n
\n\n
\n
\n\n\n
\n
\n

## View in Catalog

\n \nView in Catalog \n
\n
\n
\n\n\n\n
\n
\n